Returns the list of valid verification verbs that can be used in validation rules. Each verb corresponds to a different type of validation check.
Returns the list of valid verification verbs that can be used in validation rules. Each verb corresponds to a different type of validation check.