S7 class representing a complete markermd template with questions and metadata
Usage
markermd_template(
original_ast = NULL,
questions = list(),
metadata = markermd_metadata()
)S7 class representing a complete markermd template with questions and metadata
markermd_template(
original_ast = NULL,
questions = list(),
metadata = markermd_metadata()
)