Parse an assignment document into a Pandoc AST
Source:R/utils_parsing.R
parse_assignment_document.RdReads a qmd document, normalises any knitr-style chunk headers so the
Quarto parser accepts them, and parses it into a q2r pandoc AST.
R/utils_parsing.R
parse_assignment_document.RdReads a qmd document, normalises any knitr-style chunk headers so the
Quarto parser accepts them, and parses it into a q2r pandoc AST.