Centralized helper functions that define allowed values for rule validation. These functions serve as the single source of truth for rule validation values.
Centralized helper functions that define allowed values for rule validation. These functions serve as the single source of truth for rule validation values.