Change a markermd project's configuration
project_set.RdUpdates path entries in a project's config.yml. Only supplied arguments are
changed; an omitted (NULL) argument is left untouched. Paths are interpreted
relative to the project root.
Arguments
- path
Path to the project directory. Defaults to the working directory.
- repos
Root-relative repos directory to record. Warns if it does not exist.
- comments
Root-relative comments directory to record. Warns if it does not exist.
- template
A grading template to store in the project database: a
markermd_templateobject or a path to a template YAML file (which is parsed and imported, so an invalid file errors immediately). PassNAto clear the stored template. See alsotemplate_import().- key
Root-relative key (solution) repository directory to record. Warns if it does not exist. Pass
NAto clear a previously configured key.