Read a markermd template from a YAML file
read_template_yaml.RdParses a template YAML file and rebuilds the markermd_template object,
re-parsing the referenced assignment document to regenerate its AST. All
validation is performed by the S7 constructors as objects are built.
Arguments
- path
Path to a template
.yaml/.ymlfile.- assignment
Optional path to the assignment document, overriding the
source.pathstored in the file (useful when the template has been moved).- require_ast
When
TRUE, an assignment document that cannot be located is an error (the template editor needs the AST to draw its tree). WhenFALSE(the default), grading proceeds with an empty AST.