Validate filter condition value based on condition type
validate_filter_condition_value.RdValidates a filter condition value according to the requirements of its condition type. "node type" values are one or more node kinds from get_allowed_node_types() (excluding "Any node"), combined as a logical OR; the other types take a single character string (empty allowed).